#include <vtkLine.h>
#include <vtkActor.h>
#include <vtkRenderer.h>
#include <vtkProperty.h>
#include <vtkPointData.h>
#include <vtkCellArray.h>
#include <vtkRenderWindow.h>
#include <vtkSmartPointer.h>
#include <vtkPolyDataMapper.h>
#include <vtkParticleReader.h>
#include <vtkUnsignedCharArray.h>
#include <vtkVertexGlyphFilter.h>
#include <vtkRenderWindowInteractor.h>

#include <sstream>

using namespace std;
 
int main(int argc, char* argv[]) {
  // Vérification données d'entrée
  if (argc != 2) {
    std::cout << "ERROR: " << argv[0] << " fichier(.d)" << std::endl;
    return 1;
  }

  // Initialisation: Points & Colors
  vtkSmartPointer<vtkPoints> 		points = vtkSmartPointer<vtkPoints>           ::New();
  vtkSmartPointer<vtkCellArray>  	lines  = vtkSmartPointer<vtkCellArray> 	      ::New();
  vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();

  colors->SetName("Colors");
  colors->SetNumberOfComponents(3);

  // Lecture du Fichier: Initialisation
  string   filename = argv[1];
  ifstream file(filename.c_str());

  // Lecture du Fichier: Programmez Ici!
  unsigned nb_points = 0;
  // Exemple:
  points->InsertNextPoint(0.0f, 0.0f, 0.0f);
  points->InsertNextPoint(1.0f, 0.0f, 0.0f);
  points->InsertNextPoint(0.0f, 1.0f, 0.0f);

  vtkSmartPointer<vtkLine> line = vtkSmartPointer<vtkLine>::New();
  line ->GetPointIds()->SetId(0, 1);
  line ->GetPointIds()->SetId(1, 0);
  lines->InsertNextCell(line);

  colors->InsertNextTuple3(255, 0, 0);
  colors->InsertNextTuple3(0, 255, 0);
  colors->InsertNextTuple3(0, 0, 255);

  // Initialisation: PolyData de Vertex
  vtkSmartPointer<vtkPolyData> myPolyData = vtkSmartPointer<vtkPolyData>::New();
  myPolyData->SetPoints(points);
 
  // Transforme les points en vertex
  vtkSmartPointer<vtkVertexGlyphFilter> vertexFilter = vtkSmartPointer<vtkVertexGlyphFilter>::New();
#if VTK_MAJOR_VERSION <= 5
  vertexFilter->SetInputConnection(myPolyData->GetProducerPort());
#else
  vertexFilter->SetInputData(myPolyData);
#endif
  vertexFilter->Update();
 
  // Initialisation: PolyData avec Couleur
  vtkSmartPointer<vtkPolyData> polydata = vtkSmartPointer<vtkPolyData>::New();
  polydata->ShallowCopy(vertexFilter->GetOutput());

  // Visualization
  vtkSmartPointer<vtkPolyDataMapper> mapper = vtkSmartPointer<vtkPolyDataMapper>::New();
#if VTK_MAJOR_VERSION <= 5
  mapper->SetInputConnection(polydata->GetProducerPort());
#else
  mapper->SetInputData(polydata);
#endif
 
  vtkSmartPointer<vtkActor> actor = vtkSmartPointer<vtkActor>::New();
  actor->SetMapper(mapper);
  actor->GetProperty()->SetPointSize(5);
 
  vtkSmartPointer<vtkRenderer>     	     renderer     	    = vtkSmartPointer<vtkRenderer>    		::New();
  vtkSmartPointer<vtkRenderWindow> 	     renderWindow	    = vtkSmartPointer<vtkRenderWindow>		::New();
  vtkSmartPointer<vtkRenderWindowInteractor> renderWindowInteractor = vtkSmartPointer<vtkRenderWindowInteractor>::New();

  renderer              ->AddActor(actor);
  renderWindow          ->AddRenderer(renderer);
  renderWindowInteractor->SetRenderWindow(renderWindow);
 
  renderWindow          ->Render();
  renderWindowInteractor->Start();
 
  return EXIT_SUCCESS;
}

